Learn R Programming

munfold (version 0.3.7)

procrustes: Procrustes Rotation

Description

procrustes performs procrustes rotation, at the moment only of unfold solutions.

Usage

procrustes(x, ...)

# S3 method for unfolding procrustes(x, use=attr(x,"procrustes_use"), target, ...)

Value

a copy of x with components appropriately rotated.

Arguments

x

an object the components of which to rotate.

,

use

which of the components of x should be used as criterion for rotation.

target

a matrix to which the rotation criterion should be brought as close as possible.

...

further arguments for future methods, currently ignored.