procrustes performs procrustes rotation, at the moment only of
unfold solutions.
procrustes(x, ...)# S3 method for unfolding
procrustes(x, use=attr(x,"procrustes_use"), target, ...)
a copy of x with components appropriately rotated.
an object the components of which to rotate.
,
which of the components of x should be used
as criterion for rotation.
a matrix to which the rotation criterion should be brought as close as possible.
further arguments for future methods, currently ignored.